summaryrefslogtreecommitdiffstats
path: root/Source/cmake.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmake.cxx')
-rw-r--r--Source/cmake.cxx14
1 files changed, 11 insertions, 3 deletions
diff --git a/Source/cmake.cxx b/Source/cmake.cxx
index 6b67ef0..f54e556 100644
--- a/Source/cmake.cxx
+++ b/Source/cmake.cxx
@@ -231,9 +231,11 @@ int cmake::Generate(const std::vector<std::string>& args)
mf.GenerateMakefile();
// Before saving the cache
// if the project did not define LIBRARY_OUTPUT_PATH and
// EXECUTABLE_OUTPUT_PATH, add them now, so users
// can edit the values in the cache.
if(!cmCacheManager::GetInstance()->GetCacheValue("LIBRARY_OUTPUT_PATH"))
{
cmCacheManager::GetInstance()->AddCacheEntry("LIBRARY_OUTPUT_PATH", "",
@@ -246,6 +248,12 @@ int cmake::Generate(const std::vector<std::string>& args)
"Single output directory for building all executables.",
cmCacheManager::PATH);
}
+ if(!cmCacheManager::GetInstance()->GetCacheValue("BUILD_SHARED_LIBS"))
+ {
+ cmCacheManager::GetInstance()->AddCacheEntry("BUILD_SHARED_LIBS", "OFF",
+ "Build with shared libraries.",
+ cmCacheManager::BOOL);
+ }
cmCacheManager::GetInstance()->SaveCache(&mf);
@@ -231,9 +231,11 @@ int cmake::Generate(const std::vector<std::string>& args)
mf.GenerateMakefile();
// Before saving the cache
- // if the project did not define LIBRARY_OUTPUT_PATH and
- // EXECUTABLE_OUTPUT_PATH, add them now, so users
- // can edit the values in the cache.
+ // if the project did not define one of the entries below, add them now
+ // so users can edit the values in the cache:
+ // LIBRARY_OUTPUT_PATH
+ // EXECUTABLE_OUTPUT_PATH
+ // BUILD_SHARED_LIBS
if(!cmCacheManager::GetInstance()->GetCacheValue("LIBRARY_OUTPUT_PATH"))
{